pub enum IAddressRegistryErrors {
MasterIdCollision(MasterIdCollision),
InvalidMasterAddress(InvalidMasterAddress),
ProofOfWorkFailed(ProofOfWorkFailed),
VirtualAddressUnregistered(VirtualAddressUnregistered),
}Expand description
Container for all the IAddressRegistry custom errors.
Variants
MasterIdCollision(MasterIdCollision)
InvalidMasterAddress(InvalidMasterAddress)
ProofOfWorkFailed(ProofOfWorkFailed)
VirtualAddressUnregistered(VirtualAddressUnregistered)
Implementations
Sourceimpl IAddressRegistryErrors
impl IAddressRegistryErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IAddressRegistryErrors
impl IAddressRegistryErrors
Sourcepub fn master_id_collision(master: Address) -> Self
pub fn master_id_collision(master: Address) -> Self
Creates a MasterIdCollision error.
error MasterIdCollision(address)Sourcepub fn invalid_master_address() -> Self
pub fn invalid_master_address() -> Self
Creates a InvalidMasterAddress error.
error InvalidMasterAddress()Sourcepub fn proof_of_work_failed() -> Self
pub fn proof_of_work_failed() -> Self
Creates a ProofOfWorkFailed error.
error ProofOfWorkFailed()Sourcepub fn virtual_address_unregistered() -> Self
pub fn virtual_address_unregistered() -> Self
Creates a VirtualAddressUnregistered error.
error VirtualAddressUnregistered()Trait Implementations
Sourceimpl Clone for IAddressRegistryErrors
impl Clone for IAddressRegistryErrors
Sourcefn clone(&self) -> IAddressRegistryErrors
fn clone(&self) -> IAddressRegistryErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IAddressRegistryErrors
impl Debug for IAddressRegistryErrors
Sourceimpl<'de> Deserialize<'de> for IAddressRegistryErrors
impl<'de> Deserialize<'de> for IAddressRegistryErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IAddressRegistryErrors
Sourceimpl PartialEq for IAddressRegistryErrors
impl PartialEq for IAddressRegistryErrors
Sourcefn eq(&self, other: &IAddressRegistryErrors) -> bool
fn eq(&self, other: &IAddressRegistryErrors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IAddressRegistryErrors
impl Serialize for IAddressRegistryErrors
Sourceimpl SolInterface for IAddressRegistryErrors
impl SolInterface for IAddressRegistryErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for IAddressRegistryErrors