pub enum IAddressRegistryErrors {
MasterIdCollision(MasterIdCollision),
InvalidMasterAddress(InvalidMasterAddress),
ProofOfWorkFailed(ProofOfWorkFailed),
VirtualAddressUnregistered(VirtualAddressUnregistered),
}Expand description
Container for all the IAddressRegistry custom errors.
Variants
MasterIdCollision(MasterIdCollision)
InvalidMasterAddress(InvalidMasterAddress)
ProofOfWorkFailed(ProofOfWorkFailed)
VirtualAddressUnregistered(VirtualAddressUnregistered)
Implementations
Sourceimpl IAddressRegistryErrors
impl IAddressRegistryErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl AddrRegistryError
impl AddrRegistryError
Sourcepub const fn master_id_collision(master: Address) -> Self
pub const fn master_id_collision(master: Address) -> Self
The computed masterId is already registered to the given master address.
Sourcepub const fn invalid_master_address() -> Self
pub const fn invalid_master_address() -> Self
The caller address is not eligible to be a virtual-address master.
Sourcepub const fn proof_of_work_failed() -> Self
pub const fn proof_of_work_failed() -> Self
The registration hash does not satisfy the 32-bit proof-of-work requirement.
Sourcepub const fn virtual_address_unregistered() -> Self
pub const fn virtual_address_unregistered() -> Self
The virtual address has a valid format but its masterId is not registered.